@@ -22,4 +22,4 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-name = "py_eureka_client"
\ No newline at end of file
+version="0.9.4"
\ No newline at end of file
